Maru.Params.ParseError exception (maru_params v0.2.15)

Raised when a parameter can't be parsed or validated.

:attribute is the name of the parameter itself while :path is the full position of it within the parsed params, for example [:address, :tags, 0] for the first element of address.tags.

Summary

Functions

Callback implementation for Exception.message/1.

Human readable position of the parameter which caused the error, e.g. address.tags[0].

Functions

message(e)

Callback implementation for Exception.message/1.

position(map)

Human readable position of the parameter which caused the error, e.g. address.tags[0].